Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var (
ErrButtonValidationFailed = errors.New("invalid button configuration: missing required name or link")
)
Functions ¶
This section is empty.
Types ¶
type Button ¶
type Button struct {
Name string `yaml:"name,omitempty"` // Name is the text to display on the button
Link string `yaml:"link,omitempty"` // Link to open when the button is clicked.
}
Button is the configuration for a button on the UI
type Config ¶
type Config struct {
Title string `yaml:"title,omitempty"` // Title of the page
Description string `yaml:"description,omitempty"` // Meta description of the page
Header string `yaml:"header,omitempty"` // Header is the text at the top of the page
Logo string `yaml:"logo,omitempty"` // Logo to display on the page
Link string `yaml:"link,omitempty"` // Link to open when clicking on the logo
Buttons []Button `yaml:"buttons,omitempty"` // Buttons to display below the header
CustomCSS string `yaml:"custom-css,omitempty"` // Custom CSS to include in the page
}
Config is the configuration for the UI of Gatus
func GetDefaultConfig ¶
func GetDefaultConfig() *Config
GetDefaultConfig returns a Config struct with the default values
func (*Config) ValidateAndSetDefaults ¶
ValidateAndSetDefaults validates the UI configuration and sets the default values if necessary.
Click to show internal directories.
Click to hide internal directories.